# AWS Demos for STM32L4 Disco with SEGGER Embedded Studio

This Project is based on the Amazon FreeRTOS Device Software configuration:
* STM32L4 Discovery kit IoT node with System Workbench for STM32 and GCC
* Including AWS Greengrass Discovery, MQTT, and Thing Shadow Libraries


## Hardware Requirements

* STMicroelectronics - [STM32L4 Discovery kit IoT node](http://www.st.com/en/evaluation-tools/b-l475e-iot01a.html).

To debug the Discovery kit with Embedded Studio, convert the ST-LINK On-Board debug probe into a J-Link compatible probe.
In order to get started with ST-LINK on-board and upgrade it to a J-Link OB, just a few steps are necessary:

1. Make sure that the ST-LINK USB drivers are installed. [Download](http://www.st.com/en/development-tools/stsw-link009.html)
2. Make sure that the J-Link software package V5.12b or later is installed. [Download](https://www.segger.com/downloads/jlink)
3. Download the SEGGER STLinkReflash utility. [Download](https://www.segger.com/downloads/jlink#STLink_Reflash)
4. Start the STLinkReflash utility.
5. Agree to the license terms. 
    * ![License Terms SEGGER](https://www.segger.com/fileadmin/images/products/J-Link/Converting_ST-LINK_on-board_into_a_J-Link/jlink-stlink-stlinkreflash-1-licsegger.png)
    * ![License Terms ST](https://www.segger.com/fileadmin/images/products/J-Link/Converting_ST-LINK_on-board_into_a_J-Link/jlink-stlink-stlinkreflash-2-licst.png)
6. Connect ST-LINK on-board to PC.
7. Select *Upgrade to J-Link*.
    * ![Upgrade to J-Link](https://www.segger.com/fileadmin/images/products/J-Link/Converting_ST-LINK_on-board_into_a_J-Link/jlink-stlink-stlinkreflash-3-upgradetojlink.png)
8. Wait for operation to complete.
9. Quit the STLinkReflash utility.

[More Information](https://www.segger.com/products/debug-probes/j-link/models/other-j-links/st-link-on-board/)


## Development Environment

This project is created for **SEGGER Embedded Studio**. [More Information](https://www.segger.com/products/development-tools/embedded-studio)

Embedded Studio is available for Window, macOS and Linux.
It can be downloaded and installed for free. [Download](https://www.segger.com/downloads/embedded-studio)

Embedded Studio can freely be used for non-commercial and non-profit educational purposes without any limitation.
Embedded Studio can freely be evaluated without technical restrictions.

This project has been created and tested with Embedded Studio V3.34.


## Getting Started

### Prerequisites

* Follow the Amazon FreeRTOS Prerequisites instructions. (https://docs.aws.amazon.com/freertos/latest/userguide/freertos-getting-started.html)
* Connect and set up the target hardware. (see above)
* Download and install the development environment. (see above)

### Open and Build Your Project

1. Browse to *demos/st/stm32l475_discovery/es*.
2. Open *aws_demos.emProject* with Embedded Studio.
3. In Embedded Studio select *Build* -> *Build Solution* and make sure the project compiles without errors and warnings.

### Configure Your Project

#### Configure Your Wi-Fi Credentials

1. From the *Project Explorer* window, open *demos/include/aws_clientcredential.h*.
2. Specify values for the following #define constants:
    * clientcredentialWIFI_SSID: The SSID for your Wi-Fi network.
    * clientcredentialWIFI_PASSWORD: The password for your Wi-Fi network.
    * clientcredentialWIFI_SECURITY: The security type for your Wi-Fi network. Valid values are:
        * eWiFiSecurityOpen: Open, no security.
        * eWiFiSecurityWEP: WEP security.
        * eWiFiSecurityWPA: WPA security.
        * eWiFiSecurityWPA2: WPA2 security.

#### Configure Your AWS IoT Endpoint

You must specify a custom AWS IoT endpoint in order for the FreeRTOS sample code to connect to AWS IoT.

1. Browse to the AWS IoT console. (https://console.aws.amazon.com/iotv2/)
2. In the left navigation pane, choose *Settings*.
3. Copy your custom AWS IoT endpoint from the *Endpoint* text box. It should look like *<1234567890123>.iot.<us-east-1>.amazonaws.com*.
4. Open *demos/include/aws_clientcredential.h* and set *clientcredentialMQTT_BROKER_ENDPOINT* to your AWS IoT endpoint.

#### Configure Your AWS IoT Credentials

The certificate and private key must be hard-coded into the Amazon FreeRTOS code.  
Amazon FreeRTOS is a C language project, and the certificate and private key must be specially formatted to be added to the project.

1. In a browser window, open *demos/common/devmode_key_provisioning/CertificateConfigurationTool/CertificateConfigurator.html*.
2. Under *Certificate PEM file*, choose the *<ID>-certificate.pem.crt* you downloaded from the AWS IoT console.
3. Under *Private Key PEM file*, choose the *<ID>-private.pem.key* you downloaded from the AWS IoT console.
4. Select *Generate and save aws_clientcredential_keys.h* and save the file in *demos\common\include*. This overwrites the stub file that is in the directory.

### Run the FreeRTOS Samples

1. Rebuild your project with *Build* -> *Rebuild Solution*.
2. Sign in to the AWS IoT console. (https://console.aws.amazon.com/iotv2/)
3. In the left navigation pane, choose *Test* to open the MQTT client.
4. In the *Subscription topic* text box, type *freertos/demos/echo*, and then choose *Subscribe to topic*.
5. Start the debug session with *Debug* -> *Go*.
6. When the debugger stops at main(), let it run with *Debug* -> *Continue*.

In the MQTT client in AWS IoT, you should see the MQTT messages sent by your device.

[Getting Started Source](https://docs.aws.amazon.com/freertos/latest/userguide/getting_started_st.html)


## Changelog

* 30 Jan 2018 [JL]: Initial package.
* 23 Mar 2018 [JL]: Added SEGGER SystemView and applied patch to FreeRTOS sources.
                    Modified demo to log to SystemView if enabled.
                    Modified demo to wait for Systemview App if Button is pressed on startup.


*Last modified 23 Mar 2018 [JL]*
